CandlError

Enum CandlError 

pub enum CandlError {
    CreationError(CreationError),
    ContextError(ContextError),
    InternalError(&'static str),
}
The error of Candelabre Windowing

All the possible errors you can meet with this crate are from this type. One type to rule them all, one type to find them.

Variants



CreationError(CreationError)

OpenGL context creation error



ContextError(ContextError)

OpenGL context usage error



InternalError(&'static str)

Candelabre internal error