CandlOptions

Struct CandlOptions 

pub struct CandlOptions { /* private fields */ }
Window options

This type is an extract from luminance-windowing

Implementations

Source

impl CandlOptions

pub fn cursor_mode(&self) -> CursorMode

get the cursor current visiblity

pub fn set_cursor_mode(self, cursor_mode: CursorMode) -> Self

choose the cursor visibility

pub fn decorations(&self) -> bool

get the window current decoration status (default true)

pub fn set_decorations(self, decorations: bool) -> Self

set if the window use decoration

pub fn max_size(&self) -> Option<(u32, u32)>

get the maximal size, if set, or none otherwise

pub fn set_maw_size(self, max_size: Option<(u32, u32)>) -> Self

set the maximal size of the window

pub fn min_size(&self) -> Option<(u32, u32)>

get the minimal size, if set, or none otherwise

pub fn set_min_size(self, min_size: Option<(u32, u32)>) -> Self

set the minimal size of the window

pub fn on_top(&self) -> bool

get if the window must be always on top, or not

pub fn set_on_top(self, on_top: bool) -> Self

set if the window is always on top or not

pub fn samples(&self) -> Option<u32>

get the number of samples for multisampling

pub fn set_samples<S: Into<Option<u32>>>(self, samples: S) -> Self

choose the number of samples for multisampling

pub fn transparent(&self) -> bool

get if the window can be transparent (default false)

pub fn set_transparent(self, transparent: bool) -> Self

set the window transparency

pub fn vsync(&self) -> bool

get actual vsync configuration

pub fn set_vsync(self, vsync: bool) -> Self

set the vsync (false by default)